Learn R Programming

BSTFA (version 0.1.0)

convergence_diag: Check effective sample size and geweke diagnostic

Description

Check effective sample size and geweke diagnostic

Usage

convergence_diag(out, type = "eSS", cutoff = ifelse(type == "eSS", 100, 1.96))

Value

A list containing the parameters not meeting the convergence cutoff criteria.

Arguments

out

Output from BSTFA or BSTFAfull.

type

Character specifying which diagnostic to compute. Options are ess and geweke.

cutoff

Numeric scalar indicating the cutoff value to flag parameters that haven't converged.

Author

Adam Simpson

Examples

Run this code
data(out.sm)
attach(out.sm)
convergence_diag(out.sm)

Run the code above in your browser using DataLab